@@ -1,6 +1,6 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
- * Copyright (C) 2003 Imendio HB
+ * Copyright (C) 2003 Imendio AB
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License as
@@ -30,6 +30,7 @@
 #include <loudmouth/lm-message-node.h>
 #include <loudmouth/lm-proxy.h>
 #include <loudmouth/lm-utils.h>
+#include <loudmouth/lm-ssl.h>
 
 #undef LM_INSIDE_LOUDMOUTH_H
 
